==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/communication/kotlin/outputs/DomainPropertiesResponseVerificationRecords.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin.outputs

import kotlin.Suppress

/**
 * List of DnsRecord
 * @property dKIM A class that represents a VerificationStatus record.
 * @property dKIM2 A class that represents a VerificationStatus record.
 * @property dMARC A class that represents a VerificationStatus record.
 * @property domain A class that represents a VerificationStatus record.
 * @property sPF A class that represents a VerificationStatus record.
 */
public data class DomainPropertiesResponseVerificationRecords(
    public val dKIM: DnsRecordResponse? = null,
    public val dKIM2: DnsRecordResponse? = null,
    public val dMARC: DnsRecordResponse? = null,
    public val domain: DnsRecordResponse? = null,
    public val sPF: DnsRecordResponse? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.communication.outputs.DomainPropertiesResponseVerificationRecords):
            DomainPropertiesResponseVerificationRecords = DomainPropertiesResponseVerificationRecords(
            dKIM = javaType.dKIM().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dKIM2 = javaType.dKIM2().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dMARC = javaType.dMARC().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            domain = javaType.domain().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            sPF = javaType.sPF().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/communication/kotlin/outputs/DomainPropertiesResponseVerificationRecords.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin.outputs

import kotlin.Suppress

/**
 * List of DnsRecord
 * @property dKIM A class that represents a VerificationStatus record.
 * @property dKIM2 A class that represents a VerificationStatus record.
 * @property dMARC A class that represents a VerificationStatus record.
 * @property domain A class that represents a VerificationStatus record.
 * @property sPF A class that represents a VerificationStatus record.
 */
public data class DomainPropertiesResponseVerificationRecords(
    public val dKIM: DnsRecordResponse? = null,
    public val dKIM2: DnsRecordResponse? = null,
    public val dMARC: DnsRecordResponse? = null,
    public val domain: DnsRecordResponse? = null,
    public val sPF: DnsRecordResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.communication.outputs.DomainPropertiesResponseVerificationRecords): DomainPropertiesResponseVerificationRecords = DomainPropertiesResponseVerificationRecords(
            dKIM = javaType.dKIM().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dKIM2 = javaType.dKIM2().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dMARC = javaType.dMARC().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            domain = javaType.domain().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            sPF = javaType.sPF().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.DnsRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
